#
# spec file for package urfkill
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           urfkill
Version:        0.5.0
Release:        5.3
URL:            https://github.com/lcp/urfkill
Summary:        A daemon to control radio killswitches
License:        GPL-2.0-or-later
Group:          System/Daemons
Source:         https://github.com/lcp/urfkill/archive/%{name}-%{version}.tar.gz
Patch0:         urfkill-change-default-user.patch
Patch1:         configure_err_message.patch
Patch2:         rfkill_even_size.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext
BuildRequires:  glib2-devel >= 2.30.1
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  libexpat-devel
BuildRequires:  libgudev-1_0-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  polkit-devel
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(udev)
Requires:       polkit

%description
Urfkill is a daemon to control radio killswitches through /dev/rfkill
and supports PolicyKit authorization mechanism.

%package -n liburfkill-glib0
Summary:        The glib binding library for urfkill
Group:          System/Daemons

%description -n liburfkill-glib0
Urfkill add-on library to integrate the standard urfkill library with
the GLib thread abstraction and main loop.

%if !0%{?_crossbuild}

%package -n typelib-1_0-Urfkill-0_0
Summary:        The urfkill glib library-- Introspection bindings
Group:          System/Daemons

%description -n typelib-1_0-Urfkill-0_0
Urfkill add-on library to integrate the standard urfkill library with
the GLib thread abstraction and main loop.

This package provides the GObject Introspection bindings for urfkill.

%endif

%package -n liburfkill-glib-devel
Summary:        The glib binding library for urfkill
Group:          Development/Libraries/Other
Requires:       glib2-devel
Requires:       liburfkill-glib0 = %{version}-%{release}
Requires:       typelib-1_0-Urfkill-0_0 = %{version}-%{release}
Provides:       %{name}-devel = %{version}

%description -n liburfkill-glib-devel
Urfkill add-on library to integrate the standard urfkill library with
the GLib thread abstraction and main loop.
http://freedesktop.org/wiki/Software/urfkill

%prep
%autosetup -n %{name}-%{name}-%{version} -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure\
  --disable-static \
  --libexecdir=%{_libexecdir}/urfkill \
%if 0%{?_crossbuild}
  --disable-introspection \
%endif
  --with-session-tracking=systemd \
  --enable-gtk-doc
make %{?jobs:-j%jobs}

%install
%makeinstall
rm -f %{buildroot}%{_libdir}/*.la

%pre
getent group urfkill >/dev/null || groupadd -r urfkill
getent passwd urfkill >/dev/null || useradd -r -g urfkill -d /var/lib/urfkill -s /bin/false -c "killswitch control daemon" urfkill

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post -n liburfkill-glib0 -p /sbin/ldconfig

%postun -n liburfkill-glib0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%license COPYING
%doc AUTHORS NEWS README
%dir %{_libexecdir}/urfkill
%{_libexecdir}/urfkill/urfkilld
%{_datadir}/dbus-1/interfaces/*.xml
%{_datadir}/dbus-1/system-services/*.service
%{_datadir}/polkit-1/actions/org.freedesktop.*.policy
%doc %{_mandir}/man?/*.*
%config %{_sysconfdir}/dbus-1/system.d/*.conf
%config %{_sysconfdir}/urfkill

%files -n liburfkill-glib0
%defattr(-,root,root)
%{_libdir}/liburfkill-glib.so.*

%if !0%{?_crossbuild}

%files -n typelib-1_0-Urfkill-0_0
%defattr(-, root, root)
%{_libdir}/girepository-1.0/*.typelib
%endif

%files -n liburfkill-glib-devel
%defattr(-,root,root)
%if !0%{?_crossbuild}
%{_datadir}/gir-1.0/Urfkill-*.gir
%endif
%doc %{_datadir}/gtk-doc/html/urfkill
%{_includedir}/liburfkill-glib
%{_libdir}/liburfkill-glib.so
%{_libdir}/pkgconfig/urfkill-glib.pc

%changelog
* Fri Apr  5 2024 Dr. Werner Fink <werner@suse.de>
- Add patch rfkill_even_size.patch
  * Change size check to only fail if less than RFKILL_EVENT_SIZE_V1
    as new fields are being added to the struct
- Add patch configure_err_message.patch
  * Do not use comma in AC_MSG_ERROR() as this is used for exit status
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Apr 12 2022 Marcus Meissner <meissner@suse.com>
- https url
* Tue Jul 14 2015 werner@suse.de
- Let it build
* Wed Apr  8 2015 p.drouand@gmail.com
- Update to version 0.5.0
  * config: implement persistence via an ini file in /var/lib/urfkill
  * Implement flight mode
  * Add stubs for no session checking (breaks inhibit).
  * Simplistic port of UrfSessionChecker and UrfSeat to logind
  * Add new rfkill type: NFC
  * Use g_message() rather than g_info() for standard messages.
  * Update log levels to only display relevant killswitch addition/removal
    and important warnings
  * Enable logging to syslog, optionally with debug
  * arbitrator: set newly found devices to the saved persistent state
  * config: can't assume key_control to be enabled if there is no
    DMI information
  * Update default config file for persistence.
  * UrfArbitrator: apply review from lcp for flight mode
  * UrfConfig: apply review from lcp for persistence
  * main: handle SIGTERM
  * arbitrator: save/restore per  *type killswitch state on startup, dispose.
  * daemon: clean up UrfConfig later
  * Add persist option to UrfConfig.
  * Fix build for no session tracking.
  * Propagate/notify device state changes to UrfKillswitch objects
  * Fix errors/typos in LoginD port.
  * Allow selecting the session tracking method at build time
  * Fix include for UrfSeat
  * Rename UrfConsolekit to UrfSessionChecker
  * Rename urf  *seat and urf  *consolekit for generalization
  * Check glib version for g_type_init()
  * Add NFC to glib and docs
  * Don't crash for missing DMI
  * Add gcc warnings to urfkilld and adjust warning types
- Use download Url as source
- Remove urfkill-support-nfc-and-logind.patch; merged upstream
- Remove redundant %%clean section
* Mon Jan  6 2014 glin@suse.com
- Add urfkill-support-nfc-and-logind.patch to support NFC and
  logind (bnc#853492)
* Tue Nov  6 2012 glin@suse.com
- Amend the %%pre script
- Specify the required glib2 version
* Fri Jun  8 2012 glin@suse.com
- Version bump to 0.4.0
  + Migrate from dbus-glib to gdbus
  + Improve the input device matching
  + Fix a memory leak in urf-config
- Remove dbus-1-glib-devel from Requires
* Wed Feb 15 2012 vuntz@opensuse.org
- Move dbus xml interface files from devel subpackage to main
  subpackage: those files might be needed at runtime.
* Thu Jan 26 2012 coolo@suse.com
- some cleanups
* Mon Jan  9 2012 glin@suse.com
- Move the typelib file from liburfkill-glib0 to
  typelib-1_0-Urfkill-0_0
- Update email address.
* Tue Oct  4 2011 uli@suse.com
- cross-build workaround: gobject-introspection is impossible to
  cross-compile, so we have to disable it
* Thu Sep 15 2011 glin@suse.com
- Version bump to 0.3.0
  New Features:
  + added fork option for urfkill
  + urf-device: New property: platform
  + urf-killswitch: export UrfKillswitch to D-Bus
  + glib/urf-client: Add a new function urf_client_enumerate_devices_sync()
  + glib/urf-device: Make the "soft" property writable
  + glib/urf-killswitch: New objects for killswitches
  + Generate .xz tarballs
* Mon Jun 13 2011 glin@novell.com
- Version bump to 0.2.0
  New Features:
  + All DBus methods, signals, and properties were revised and amended
  + Support the individual key control settings for each user
  + GObject introspection support in liburfkill-glib
  + Documents for the daemon, the DBus interfaces, and liburfkill-glib
  + Test cases for the daemon and liburkill-glib
- Enable gobject-introspection
* Tue Apr 19 2011 glin@novell.com
- Version bump to 0.1.1
- New dependency: expat
- Drop merged patches
  + urfkill-correct-config-name.patch
  + urfkill-new-input-devices.patch
- Remove rpmlintrc (bnc#688328)
* Tue Mar 15 2011 glin@novell.com
- Add urfkill-new-input-devices.patch to support more input devices
- Add urfkill-rpmlintrc for openSUSE 11.4 and wait for security review
* Tue Mar 15 2011 glin@novell.com
- Add urfkill-correct-config-name.patch to correct the config variable
* Tue Mar  1 2011 glin@novell.com
- Version bump to 0.1.0
- Add urfkill-change-default-user.patch to change the default user
- Drop deprecated patches:
  + urfkill-polkit-0.9.patch
  + urfkill-drop-privilege.patch
  + urfkill-killswitch-error-handle.patch
* Tue Nov 23 2010 glin@novell.com
- Amend urfkill-drop-privilege.patch to setuid to the dedicated user,
  urfkill, instead of nobody. bnc#646608
- Create the user, urfkill, in %%pre
- Add urfkill-killswitch-error-handle.patch to handle critical errors
  from urf_killswitch
* Wed Nov 10 2010 glin@novell.com
- Add urfkill-drop-privilege.patch to drop privilege after open
  /dev/rfkill. bnc#646608
* Tue Oct 12 2010 glin@novell.com
- Update to 0.0.1
  + License liburfkill-glib under LGPL v2.1
  + Support Block/Unblock by index
- Add patch urfkill-polkit-0.9.patch to support PolicyKit 0.9
* Fri Oct  1 2010 glin@novell.com
- Initial import 0.0.0~20101001
